@@ -4,7 +4,7 @@
  *
  */
 
-#define MOD_SCGI_VERSION "1.12"
+#define MOD_SCGI_VERSION "1.13"
 #define SCGI_PROTOCOL_VERSION "1"
 
 #include "ap_config.h"
@@ -138,9 +138,7 @@ static int scgi_map_location(request_rec *r)
 static void log_err(const char *file, int line, request_rec *r,
                     apr_status_t status, const char *msg)
 {
-    char buf[256] = "";
-    apr_strerror(status, buf, sizeof(buf));
-    ap_log_rerror(file, line, APLOG_ERR, status, r, "scgi: %s: %s", buf, msg);
+    ap_log_rerror(file, line, APLOG_ERR, status, r, "scgi: %s", msg);
 }
 
 static void log_debug(const char *file, int line, request_rec *r, const
@@ -321,8 +319,10 @@ send_headers(request_rec *r, struct sockbuff *s)
     if (!t)
 	    return APR_ENOMEM;
     /* CONTENT_LENGTH must come first and always be present */
-    add_header(t, "CONTENT_LENGTH",
-               apr_psprintf(r->pool, "%ld", r->remaining));
+    buf = lookup_header(r, "Content-Length");
+    if (buf == NULL)
+	    buf = "0";
+    add_header(t, "CONTENT_LENGTH",  buf);
     add_header(t, "SCGI", SCGI_PROTOCOL_VERSION);
     add_header(t, "SERVER_SOFTWARE", ap_get_server_version());
     add_header(t, "SERVER_PROTOCOL", r->protocol);
